#region Using directives

using System;
using System.Text;
using System.Drawing;
using System.Runtime.InteropServices;

#endregion

namespace BitmapHandler
{
    public class BitmapHandler : IDisposable
    {
        private Bitmap bmp; // the bitmap to draw on
        private Random rnd;
        private int btop; // top y of drawn area
        private int bleft; // top x of drawn area
        private int bbottom; // bottom y of drawn area
        private int bright; // bottom x of drawn area


       // constructor
        public BitmapHandler(Bitmap bm, int top, int left, int bottom, int right)
        {
            bmp = bm;
            rnd = new Random();
            btop = top;
            bleft = left;
            bbottom = bottom;
            bright = right;
        }

        // public properties
        public Bitmap ControlRef
        { get { return bmp; } }



        public Bitmap Value
        { get { return bmp;}}


        // public methods

        public int timer(int[]x, int[]y, int[]col, double[] spread, int n, Color bcol)
        {
            int i, nx, ny; 
            for (i = 0; i < n; i++)
            {
                // this guards against out of range initial inputs
                // it's inefficient here and should be done at particle creation time
                // x[i] = Math.Min(Math.Max(x[i], bleft), bright);
                //y[i] = Math.Min(Math.Max(y[i], btop), bbottom);
                // calculate next position
                nx = Math.Min(Math.Max(x[i] + (int)((2 * rnd.NextDouble() - 1) * spread[i]), bleft), bright);
                ny = Math.Min(Math.Max(y[i] + 1, btop), bbottom);
                if (bmp.GetPixel(nx, ny) != bcol)
                {
                   ny = y[i];
                }
                if (bmp.GetPixel(nx, ny) == bcol)
                {
                    // undraw old particle position
                    bmp.SetPixel(x[i], y[i], Color.Black);
                    x[i] = nx;
                    y[i] = ny;
                    // draw it or lose it off the bottom
                    if (ny < bbottom)
                    {
                        bmp.SetPixel(nx, ny, Color.FromArgb(col[i]));
                    }
                    else
                    {
                        x[i] = x[n - 1];
                        y[i] = y[n - 1];
                        col[i] = col[n - 1];
                        spread[i] = spread[n - 1];
                        n = n - 1;
                    }
                }
            }
            return n;
        }

        public void Dispose()
        {
            bmp = null;
        }
    }


}
